You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beehive.apache.org by ri...@apache.org on 2005/10/19 07:30:10 UTC

svn commit: r326398 - in /beehive/trunk/netui: src/compiler-core/org/apache/beehive/netui/compiler/genmodel/ test/webapps/drt/coreWeb/bugs/j977/ test/webapps/drt/coreWeb/bugs/j977/base/ test/webapps/drt/coreWeb/bugs/j977/derived/ test/webapps/drt/testR...

Author: rich
Date: Tue Oct 18 22:29:54 2005
New Revision: 326398

URL: http://svn.apache.org/viewcvs?rev=326398&view=rev
Log:
Fix for http://issues.apache.org/jira/browse/BEEHIVE-977 : In a derived page flow, forwarding to a base class action from another base class action blows up

tests: bvt in netui (WinXP)
BB: same (linux)


Added:
    beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/
    beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/base/
    beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/base/Controller.jpf   (with props)
    beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/base/base.jsp   (with props)
    beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/derived/
    beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/derived/Controller.jpf   (with props)
    beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/derived/index.jsp   (with props)
    beehive/trunk/netui/test/webapps/drt/testRecorder/tests/J977.xml   (with props)
Modified:
    beehive/trunk/netui/src/compiler-core/org/apache/beehive/netui/compiler/genmodel/GenForwardModel.java
    beehive/trunk/netui/test/webapps/drt/testRecorder/config/testRecorder-tests.xml

Modified: beehive/trunk/netui/src/compiler-core/org/apache/beehive/netui/compiler/genmodel/GenForwardModel.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/netui/src/compiler-core/org/apache/beehive/netui/compiler/genmodel/GenForwardModel.java?rev=326398&r1=326397&r2=326398&view=diff
==============================================================================
--- beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/base/Controller.jpf (added)
+++ beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/base/Controller.jpf Tue Oct 18 22:29:54 2005
@@ -0,0 +1,33 @@
+/*
+ * Copyright 2004 The Apache Software Foundation.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * $Header:$
+ */
+package bugs.j977.base;
+
+import org.apache.beehive.netui.pageflow.PageFlowController;
+import org.apache.beehive.netui.pageflow.Forward;
+import org.apache.beehive.netui.pageflow.annotations.Jpf;
+
+@Jpf.Controller(
+    inheritLocalPaths=true,
+    simpleActions={
+        @Jpf.SimpleAction(name="baseAction", path="base.jsp"),
+        @Jpf.SimpleAction(name="fwdToBaseAction", action="baseAction")
+    }
+)
+public abstract class Controller extends PageFlowController
+{
+}

Propchange: beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/base/Controller.jpf
------------------------------------------------------------------------------
    svn:eol-style = native

Added: beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/base/base.jsp
URL: http://svn.apache.org/viewcvs/beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/base/base.jsp?rev=326398&view=auto
==============================================================================
--- beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/base/base.jsp (added)
+++ beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/base/base.jsp Tue Oct 18 22:29:54 2005
@@ -0,0 +1,21 @@
+<%@ page language="java" contentType="text/html;charset=UTF-8"%>
+<%@ taglib prefix="netui" uri="http://beehive.apache.org/netui/tags-html-1.0"%>
+<%@ taglib prefix="netui-data" uri="http://beehive.apache.org/netui/tags-databinding-1.0"%>
+<%@ taglib prefix="netui-template" uri="http://beehive.apache.org/netui/tags-template-1.0"%>
+
+
+<netui:html>
+    <head>
+        <netui:base/>
+    </head>
+    <netui:body>
+        <h3>base1.jsp</h3>
+
+        Success!
+        <br/>
+        <netui:anchor action="begin">start over</netui:anchor>
+    </netui:body>
+</netui:html>
+
+  
+

Propchange: beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/base/base.jsp
------------------------------------------------------------------------------
    svn:eol-style = native

Added: beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/derived/Controller.jpf
URL: http://svn.apache.org/viewcvs/beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/derived/Controller.jpf?rev=326398&view=auto
==============================================================================
--- beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/derived/Controller.jpf (added)
+++ beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/derived/Controller.jpf Tue Oct 18 22:29:54 2005
@@ -0,0 +1,31 @@
+/*
+ * Copyright 2004 The Apache Software Foundation.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * $Header:$
+ */
+package bugs.j977.derived;
+
+import org.apache.beehive.netui.pageflow.PageFlowController;
+import org.apache.beehive.netui.pageflow.Forward;
+import org.apache.beehive.netui.pageflow.annotations.Jpf;
+
+@Jpf.Controller(
+    simpleActions={
+        @Jpf.SimpleAction(name="begin", path="index.jsp")
+    }
+)
+public class Controller extends bugs.j977.base.Controller
+{
+}

Propchange: beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/derived/Controller.jpf
------------------------------------------------------------------------------
    svn:eol-style = native

Added: beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/derived/index.jsp
URL: http://svn.apache.org/viewcvs/beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/derived/index.jsp?rev=326398&view=auto
==============================================================================
--- beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/derived/index.jsp (added)
+++ beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/derived/index.jsp Tue Oct 18 22:29:54 2005
@@ -0,0 +1,25 @@
+<%@ page language="java" contentType="text/html;charset=UTF-8"%>
+<%@ taglib prefix="netui" uri="http://beehive.apache.org/netui/tags-html-1.0"%>
+<%@ taglib prefix="netui-data" uri="http://beehive.apache.org/netui/tags-databinding-1.0"%>
+<%@ taglib prefix="netui-template" uri="http://beehive.apache.org/netui/tags-template-1.0"%>
+
+
+<netui:html>
+    <head>
+        <netui:base/>
+    </head>
+    <netui:body>
+        <h3>${pageFlow.URI}</h3>
+
+        This test ensures that if a base class action forwards to another action, it forwards to the
+        action in the derived page flow, if there is an overriding one there.
+        <br/>
+        <br/>
+        <netui:anchor action="baseAction">baseAction</netui:anchor> (works)
+        <br/>
+        <netui:anchor action="fwdToBaseAction">fwdToBaseAction</netui:anchor> (busted, until this bug is fixed)
+    </netui:body>
+</netui:html>
+
+  
+

Propchange: beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/derived/index.jsp
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: beehive/trunk/netui/test/webapps/drt/testRecorder/config/testRecorder-tests.xml
URL: http://svn.apache.org/viewcvs/beehive/trunk/netui/test/webapps/drt/testRecorder/config/testRecorder-tests.xml?rev=326398&r1=326397&r2=326398&view=diff
==============================================================================
--- beehive/trunk/netui/test/webapps/drt/testRecorder/config/testRecorder-tests.xml (original)
+++ beehive/trunk/netui/test/webapps/drt/testRecorder/config/testRecorder-tests.xml Tue Oct 18 22:29:54 2005
@@ -4867,6 +4867,16 @@
          </categories>
       </test>
       <test>
+         <name>J977</name>
+         <description>Test to ensure that if a base class action forwards to another action, it forwards to the action in the derived page flow, if there is an overriding one there.</description>
+         <webapp>coreWeb</webapp>
+         <categories>
+            <category>bvt</category>
+            <category>bvt.struts11</category>
+            <category>jiraBugs</category>
+         </categories>
+      </test>
+      <test>
          <name>JpfScopedFormsTest49</name>
          <description>JpfScopedFormsTest49</description>
          <webapp>coreWeb</webapp>

Added: beehive/trunk/netui/test/webapps/drt/testRecorder/tests/J977.xml
URL: http://svn.apache.org/viewcvs/beehive/trunk/netui/test/webapps/drt/testRecorder/tests/J977.xml?rev=326398&view=auto
==============================================================================
--- beehive/trunk/netui/test/webapps/drt/testRecorder/tests/J977.xml (added)
+++ beehive/trunk/netui/test/webapps/drt/testRecorder/tests/J977.xml Tue Oct 18 22:29:54 2005
@@ -0,0 +1,399 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<ses:recorderSession xmlns:ses="http://beehive.apache.org/netui/tools/testrecorder/2004/session">
+   <ses:sessionName>J977</ses:sessionName>
+   <ses:tester>rich</ses:tester>
+   <ses:startDate>18 Oct 2005, 11:17:10.794 PM MDT</ses:startDate>
+   <ses:description>Test to ensure that if a base class action forwards to another action, it forwards to the action in the derived page flow, if there is an overriding one there.</ses:description>
+   <ses:tests>
+      <ses:test>
+         <ses:testNumber>1</ses:testNumber>
+         <ses:request>
+            <ses:protocol>HTTP</ses:protocol>
+            <ses:protocolVersion>1.1</ses:protocolVersion>
+            <ses:host>localhost</ses:host>
+            <ses:port>8080</ses:port>
+            <ses:uri>/coreWeb/bugs/j977/derived/Controller.jpf</ses:uri>
+            <ses:method>GET</ses:method>
+            <ses:parameters/>
+            <ses:cookies>
+               <ses:cookie>
+                  <ses:name>JSESSIONID</ses:name>
+                  <ses:value>1AF9F51822D726737723D5CE06D9A6AC</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>Country</ses:name>
+                  <ses:value>US</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>nde-textsize</ses:name>
+                  <ses:value>16px</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>Language</ses:name>
+                  <ses:value>en</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>JSESSIONID</ses:name>
+                  <ses:value>8ahnbsqr36fe5</ses:value>
+               </ses:cookie>
+            </ses:cookies>
+            <ses:headers>
+               <ses:header>
+                  <ses:name>accept</ses:name>
+                  <ses:value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>accept-charset</ses:name>
+                  <ses:value>ISO-8859-1,utf-8;q=0.7,*;q=0.7</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>accept-encoding</ses:name>
+                  <ses:value>gzip,deflate</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>accept-language</ses:name>
+                  <ses:value>en-us,en;q=0.7,ja;q=0.3</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>connection</ses:name>
+                  <ses:value>keep-alive</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>cookie</ses:name>
+                  <ses:value>JSESSIONID=1AF9F51822D726737723D5CE06D9A6AC; Country=US; nde-textsize=16px; Language=en; JSESSIONID=8ahnbsqr36fe5</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>host</ses:name>
+                  <ses:value>localhost:8080</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>keep-alive</ses:name>
+                  <ses:value>300</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>user-agent</ses:name>
+                  <ses:value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7</ses:value>
+               </ses:header>
+            </ses:headers>
+         </ses:request>
+         <ses:response>
+            <ses:statusCode>200</ses:statusCode>
+            <ses:reason/>
+            <ses:responseBody><![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <base href="http://localhost:8080/coreWeb/bugs/j977/derived/index.jsp">
+    </head>
+    <body>
+        <h3>/bugs/j977/derived/Controller.jpf</h3>
+
+        This test ensures that if a base class action forwards to another action, it forwards to the
+        action in the derived page flow, if there is an overriding one there.
+        <br/>
+        <br/>
+        <a href="/coreWeb/bugs/j977/derived/baseAction.do">baseAction</a> (works)
+        <br/>
+        <a href="/coreWeb/bugs/j977/derived/fwdToBaseAction.do">fwdToBaseAction</a> (busted, until this bug is fixed)
+    </body>
+
+</html>]]></ses:responseBody>
+         </ses:response>
+      </ses:test>
+      <ses:test>
+         <ses:testNumber>2</ses:testNumber>
+         <ses:request>
+            <ses:protocol>HTTP</ses:protocol>
+            <ses:protocolVersion>1.1</ses:protocolVersion>
+            <ses:host>localhost</ses:host>
+            <ses:port>8080</ses:port>
+            <ses:uri>/coreWeb/bugs/j977/derived/baseAction.do</ses:uri>
+            <ses:method>GET</ses:method>
+            <ses:parameters/>
+            <ses:cookies>
+               <ses:cookie>
+                  <ses:name>JSESSIONID</ses:name>
+                  <ses:value>1AF9F51822D726737723D5CE06D9A6AC</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>Country</ses:name>
+                  <ses:value>US</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>nde-textsize</ses:name>
+                  <ses:value>16px</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>Language</ses:name>
+                  <ses:value>en</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>JSESSIONID</ses:name>
+                  <ses:value>8ahnbsqr36fe5</ses:value>
+               </ses:cookie>
+            </ses:cookies>
+            <ses:headers>
+               <ses:header>
+                  <ses:name>accept</ses:name>
+                  <ses:value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>accept-charset</ses:name>
+                  <ses:value>ISO-8859-1,utf-8;q=0.7,*;q=0.7</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>accept-encoding</ses:name>
+                  <ses:value>gzip,deflate</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>accept-language</ses:name>
+                  <ses:value>en-us,en;q=0.7,ja;q=0.3</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>connection</ses:name>
+                  <ses:value>keep-alive</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>cookie</ses:name>
+                  <ses:value>JSESSIONID=1AF9F51822D726737723D5CE06D9A6AC; Country=US; nde-textsize=16px; Language=en; JSESSIONID=8ahnbsqr36fe5</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>host</ses:name>
+                  <ses:value>localhost:8080</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>keep-alive</ses:name>
+                  <ses:value>300</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>referer</ses:name>
+                  <ses:value>http://localhost:8080/coreWeb/bugs/j977/derived/Controller.jpf</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>user-agent</ses:name>
+                  <ses:value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7</ses:value>
+               </ses:header>
+            </ses:headers>
+         </ses:request>
+         <ses:response>
+            <ses:statusCode>200</ses:statusCode>
+            <ses:reason/>
+            <ses:responseBody><![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <base href="http://localhost:8080/coreWeb/bugs/j977/base/base.jsp">
+    </head>
+    <body>
+        <h3>base1.jsp</h3>
+
+        Success!
+        <br/>
+        <a href="/coreWeb/bugs/j977/derived/begin.do">start over</a>
+    </body>
+
+</html>]]></ses:responseBody>
+         </ses:response>
+      </ses:test>
+      <ses:test>
+         <ses:testNumber>3</ses:testNumber>
+         <ses:request>
+            <ses:protocol>HTTP</ses:protocol>
+            <ses:protocolVersion>1.1</ses:protocolVersion>
+            <ses:host>localhost</ses:host>
+            <ses:port>8080</ses:port>
+            <ses:uri>/coreWeb/bugs/j977/derived/begin.do</ses:uri>
+            <ses:method>GET</ses:method>
+            <ses:parameters/>
+            <ses:cookies>
+               <ses:cookie>
+                  <ses:name>JSESSIONID</ses:name>
+                  <ses:value>1AF9F51822D726737723D5CE06D9A6AC</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>Country</ses:name>
+                  <ses:value>US</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>nde-textsize</ses:name>
+                  <ses:value>16px</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>Language</ses:name>
+                  <ses:value>en</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>JSESSIONID</ses:name>
+                  <ses:value>8ahnbsqr36fe5</ses:value>
+               </ses:cookie>
+            </ses:cookies>
+            <ses:headers>
+               <ses:header>
+                  <ses:name>accept</ses:name>
+                  <ses:value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>accept-charset</ses:name>
+                  <ses:value>ISO-8859-1,utf-8;q=0.7,*;q=0.7</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>accept-encoding</ses:name>
+                  <ses:value>gzip,deflate</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>accept-language</ses:name>
+                  <ses:value>en-us,en;q=0.7,ja;q=0.3</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>connection</ses:name>
+                  <ses:value>keep-alive</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>cookie</ses:name>
+                  <ses:value>JSESSIONID=1AF9F51822D726737723D5CE06D9A6AC; Country=US; nde-textsize=16px; Language=en; JSESSIONID=8ahnbsqr36fe5</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>host</ses:name>
+                  <ses:value>localhost:8080</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>keep-alive</ses:name>
+                  <ses:value>300</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>referer</ses:name>
+                  <ses:value>http://localhost:8080/coreWeb/bugs/j977/derived/baseAction.do</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>user-agent</ses:name>
+                  <ses:value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7</ses:value>
+               </ses:header>
+            </ses:headers>
+         </ses:request>
+         <ses:response>
+            <ses:statusCode>200</ses:statusCode>
+            <ses:reason/>
+            <ses:responseBody><![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <base href="http://localhost:8080/coreWeb/bugs/j977/derived/index.jsp">
+    </head>
+    <body>
+        <h3>/bugs/j977/derived/Controller.jpf</h3>
+
+        This test ensures that if a base class action forwards to another action, it forwards to the
+        action in the derived page flow, if there is an overriding one there.
+        <br/>
+        <br/>
+        <a href="/coreWeb/bugs/j977/derived/baseAction.do">baseAction</a> (works)
+        <br/>
+        <a href="/coreWeb/bugs/j977/derived/fwdToBaseAction.do">fwdToBaseAction</a> (busted, until this bug is fixed)
+    </body>
+
+</html>]]></ses:responseBody>
+         </ses:response>
+      </ses:test>
+      <ses:test>
+         <ses:testNumber>4</ses:testNumber>
+         <ses:request>
+            <ses:protocol>HTTP</ses:protocol>
+            <ses:protocolVersion>1.1</ses:protocolVersion>
+            <ses:host>localhost</ses:host>
+            <ses:port>8080</ses:port>
+            <ses:uri>/coreWeb/bugs/j977/derived/fwdToBaseAction.do</ses:uri>
+            <ses:method>GET</ses:method>
+            <ses:parameters/>
+            <ses:cookies>
+               <ses:cookie>
+                  <ses:name>JSESSIONID</ses:name>
+                  <ses:value>1AF9F51822D726737723D5CE06D9A6AC</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>Country</ses:name>
+                  <ses:value>US</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>nde-textsize</ses:name>
+                  <ses:value>16px</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>Language</ses:name>
+                  <ses:value>en</ses:value>
+               </ses:cookie>
+               <ses:cookie>
+                  <ses:name>JSESSIONID</ses:name>
+                  <ses:value>8ahnbsqr36fe5</ses:value>
+               </ses:cookie>
+            </ses:cookies>
+            <ses:headers>
+               <ses:header>
+                  <ses:name>accept</ses:name>
+                  <ses:value>text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>accept-charset</ses:name>
+                  <ses:value>ISO-8859-1,utf-8;q=0.7,*;q=0.7</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>accept-encoding</ses:name>
+                  <ses:value>gzip,deflate</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>accept-language</ses:name>
+                  <ses:value>en-us,en;q=0.7,ja;q=0.3</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>connection</ses:name>
+                  <ses:value>keep-alive</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>cookie</ses:name>
+                  <ses:value>JSESSIONID=1AF9F51822D726737723D5CE06D9A6AC; Country=US; nde-textsize=16px; Language=en; JSESSIONID=8ahnbsqr36fe5</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>host</ses:name>
+                  <ses:value>localhost:8080</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>keep-alive</ses:name>
+                  <ses:value>300</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>referer</ses:name>
+                  <ses:value>http://localhost:8080/coreWeb/bugs/j977/derived/begin.do</ses:value>
+               </ses:header>
+               <ses:header>
+                  <ses:name>user-agent</ses:name>
+                  <ses:value>Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7</ses:value>
+               </ses:header>
+            </ses:headers>
+         </ses:request>
+         <ses:response>
+            <ses:statusCode>200</ses:statusCode>
+            <ses:reason/>
+            <ses:responseBody><![CDATA[<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+	"http://www.w3.org/TR/html4/loose.dtd">
+<html lang="en">
+
+    <head>
+        <base href="http://localhost:8080/coreWeb/bugs/j977/base/base.jsp">
+    </head>
+    <body>
+        <h3>base1.jsp</h3>
+
+        Success!
+        <br/>
+        <a href="/coreWeb/bugs/j977/derived/begin.do">start over</a>
+    </body>
+
+</html>]]></ses:responseBody>
+         </ses:response>
+      </ses:test>
+   </ses:tests>
+   <ses:endDate>18 Oct 2005, 11:17:19.988 PM MDT</ses:endDate>
+   <ses:testCount>4</ses:testCount>
+</ses:recorderSession>

Propchange: beehive/trunk/netui/test/webapps/drt/testRecorder/tests/J977.xml
------------------------------------------------------------------------------
    svn:eol-style = native
--- beehive/trunk/netui/src/compiler-core/org/apache/beehive/netui/compiler/genmodel/GenForwardModel.java (original)
+++ beehive/trunk/netui/src/compiler-core/org/apache/beehive/netui/compiler/genmodel/GenForwardModel.java Tue Oct 18 22:29:54 2005
@@ -125,13 +125,13 @@
             boolean contextRelative = true;
             if ( ! path.startsWith( "/" ) )
             {
-                //
                 // If this annotation came from a base class, and if inheritLocalPaths is true on the Controller
                 // annotation, then make the path relative to the base class module.
                 //
                 TypeDeclaration containingType = annotation.getContainingType();
                 if ( ! CompilerUtils.typesAreEqual( jclass, containingType ) 
-                     && parent.getFlowControllerInfo().getMergedControllerAnnotation().isInheritLocalPaths() )
+                     && parent.getFlowControllerInfo().getMergedControllerAnnotation().isInheritLocalPaths()
+                     && ! path.endsWith(ACTION_EXTENSION_DOT))
                 {
                     // TODO: when we no longer support Struts 1.1, we can simply use the 'module' property
                     // to make this forward relative to the base class module.
@@ -125,13 +125,13 @@
                 // If this annotation came from a base class, and if inheritLocalPaths is true on the Controller
-                // annotation, then make the path relative to the base class module.
-                //
+                // annotation, then make the path relative to the base class module.  Do NOT do this if it's a
+                // path to an action; actions are always run relative to the current controller.
                 TypeDeclaration containingType = annotation.getContainingType();
                 if ( ! CompilerUtils.typesAreEqual( jclass, containingType ) 

Added: beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/base/Controller.jpf
URL: http://svn.apache.org/viewcvs/beehive/trunk/netui/test/webapps/drt/coreWeb/bugs/j977/base/Controller.jpf?rev=326398&view=auto
==============================================================================